
import React, { Component } from 'react';
import ModalDialog from 'components/ModalDialog';

import style from './ImageCarousel.module.scss';

const Arrow = ({ onArrowClick = () => { }, glyph }) => (
    <div className={style.slideArrow}
        onClick={onArrowClick}>
        {glyph}
    </div>
);

class ImageCarousel extends Component {

    state = {
        currentImageIndex: 0
    };

    previousSlide = () => {
        const { images = [] } = this.props;
        const lastIndex = images.length - 1;
        const { currentImageIndex } = this.state;
        const isFirstImage = currentImageIndex === 0;
        const index = isFirstImage ? lastIndex : currentImageIndex - 1;

        this.setState({
            currentImageIndex: index
        });
    }

    nextSlide = () => {
        const { images = [] } = this.props;
        const lastIndex = images.length - 1;
        const { currentImageIndex } = this.state;
        const isLastImage = currentImageIndex === lastIndex;
        const index = isLastImage ? 0 : currentImageIndex + 1;

        this.setState({
            currentImageIndex: index
        });
    }

    render() {
        const { show = false, images = [], onClose = () => { } } = this.props;
        const { currentImageIndex } = this.state;
        const curImage = images[currentImageIndex] || {};
        return (
            <ModalDialog className={style.imageCarousel} show={show}>
                <div>{`Total images: ${images.length}`}</div>
                <div className={style.content}>
                    <Arrow onArrowClick={this.previousSlide} glyph="&#9664;" />
                    <img src={curImage.url} alt={curImage.alt} />
                    <Arrow onArrowClick={this.nextSlide} glyph="&#9654;" />
                </div>
                <button className={style.closeButton} onClick={onClose}>Close</button>
            </ModalDialog>
        );
    }

}

export default ImageCarousel;