
import { URL } from 'constants/urls';

async function get(url) {

    const response = await fetch(url);

    if (response.ok) {
        const data = await response.json();
        return data;
    }
    else {
        const message = `Following api request resulted in an exception.
                Url: ${response.url},
                Status: ${response.status},
                StatusText: ${response.statusText}`;
        throw Error(message);
    }
}

class ApiClient {

    init(store) {
        this.store = store;
    }

    async getCategoryData() {
        return get(URL.CATEGORY);
    }

    async getProductDetails(id) {
        const { category: { items = [] } = {} } = this.store.getState();
        const product = items.find(item => item.id === id);
        return Promise.resolve(product)
    }
}

export default new ApiClient();